==> qt6-multimedia-6.2.0beta2-1-x86_64.pkg.tar.zst: usr/include/qt6/QtMultimedia/6.2.0/QtMultimedia/private/qplatformmediaintegration_p.h <==
/****************************************************************************
**
** Copyright (C) 2021 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/
#ifndef QPLATFORMMEDIAINTEGRATION_H
#define QPLATFORMMEDIAINTEGRATION_H

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists purely as an
// implementation detail.  This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//

#include <private/qtmultimediaglobal_p.h>
#include <qmediarecorder.h>

QT_BEGIN_NAMESPACE

class QMediaPlayer;
class QAudioDecoder;
class QCamera;
class QMediaRecorder;
class QImageCapture;
class QMediaDevices;
class QPlatformMediaDevices;
class QPlatformMediaCaptureSession;
class QPlatformMediaPlayer;
class QPlatformAudioDecoder;
class QPlatformCamera;
class QPlatformMediaEncoder;
class QPlatformImageCapture;
class QPlatformMediaFormatInfo;
class QObject;
class QPlatformVideoSink;
class QVideoSink;
class QAudioInput;
class QAudioOutput;
class QPlatformAudioInput;
class QPlatformAudioOutput;

class Q_MULTIMEDIA_EXPORT QPlatformMediaIntegration
{
public:
    static QPlatformMediaIntegration *instance();

    // API to be able to test with a mock backend
    static void setIntegration(QPlatformMediaIntegration *);

    virtual ~QPlatformMediaIntegration();
    virtual QPlatformMediaDevices *devices() = 0;
    virtual QPlatformMediaFormatInfo *formatInfo() = 0;

    virtual QPlatformAudioDecoder *createAudioDecoder(QAudioDecoder *) { return nullptr; }
    virtual QPlatformMediaCaptureSession *createCaptureSession() { return nullptr; }
    virtual QPlatformMediaPlayer *createPlayer(QMediaPlayer *) { return nullptr; }
    virtual QPlatformCamera *createCamera(QCamera *) { return nullptr; }
    virtual QPlatformMediaEncoder *createEncoder(QMediaRecorder *) { return nullptr; }
    virtual QPlatformImageCapture *createImageCapture(QImageCapture *) { return nullptr; }

    virtual QPlatformAudioInput *createAudioInput(QAudioInput *);
    virtual QPlatformAudioOutput *createAudioOutput(QAudioOutput *);

    virtual QPlatformVideoSink *createVideoSink(QVideoSink *) { return nullptr; }
};

QT_END_NAMESPACE


#endif // QPLATFORMMEDIAINTERFACE_H

==> qt6-multimedia-6.4.0beta1-4-x86_64.pkg.tar.zst: usr/include/qt6/QtMultimedia/6.4.0/QtMultimedia/private/qplatformmediaintegration_p.h <==
/****************************************************************************
**
** Copyright (C) 2021 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/
#ifndef QPLATFORMMEDIAINTEGRATION_H
#define QPLATFORMMEDIAINTEGRATION_H

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists purely as an
// implementation detail.  This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//

#include <private/qtmultimediaglobal_p.h>
#include <qmediarecorder.h>

QT_BEGIN_NAMESPACE

class QMediaPlayer;
class QAudioDecoder;
class QCamera;
class QMediaRecorder;
class QImageCapture;
class QMediaDevices;
class QPlatformMediaDevices;
class QPlatformMediaCaptureSession;
class QPlatformMediaPlayer;
class QPlatformAudioDecoder;
class QPlatformCamera;
class QPlatformMediaRecorder;
class QPlatformImageCapture;
class QPlatformMediaFormatInfo;
class QObject;
class QPlatformVideoSink;
class QVideoSink;
class QAudioInput;
class QAudioOutput;
class QPlatformAudioInput;
class QPlatformAudioOutput;
class QPlatformVideoDevices;

class Q_MULTIMEDIA_EXPORT QPlatformMediaIntegration
{
public:
    static QPlatformMediaIntegration *instance();

    // API to be able to test with a mock backend
    static void setIntegration(QPlatformMediaIntegration *);

    virtual ~QPlatformMediaIntegration();
    virtual QPlatformMediaFormatInfo *formatInfo() = 0;

    virtual QList<QCameraDevice> videoInputs();
    virtual QPlatformCamera *createCamera(QCamera *) { return nullptr; }

    virtual QPlatformAudioDecoder *createAudioDecoder(QAudioDecoder *) { return nullptr; }
    virtual QPlatformMediaCaptureSession *createCaptureSession() { return nullptr; }
    virtual QPlatformMediaPlayer *createPlayer(QMediaPlayer *) { return nullptr; }
    virtual QPlatformMediaRecorder *createRecorder(QMediaRecorder *) { return nullptr; }
    virtual QPlatformImageCapture *createImageCapture(QImageCapture *) { return nullptr; }

    virtual QPlatformAudioInput *createAudioInput(QAudioInput *);
    virtual QPlatformAudioOutput *createAudioOutput(QAudioOutput *);

    virtual QPlatformVideoSink *createVideoSink(QVideoSink *) { return nullptr; }

protected:
    QPlatformVideoDevices *m_videoDevices = nullptr;
};

QT_END_NAMESPACE


#endif // QPLATFORMMEDIAINTERFACE_H
